// Copyright 2012 The Rust Project Developers. See the COPYRIGHT
// file at the top-level directory of this distribution and at
// http://rust-lang.org/COPYRIGHT.
//
// Licensed under the Apache License, Version 2.0 <LICENSE-APACHE or
// http://www.apache.org/licenses/LICENSE-2.0> or the MIT license
// <LICENSE-MIT or http://opensource.org/licenses/MIT>, at your
// option. This file may not be copied, modified, or distributed
// except according to those terms.

#![feature(nll)]

struct AtomicRefMut<'a> {
    value: &'a mut i32,
    borrow: AtomicBorrowRefMut,
}

struct AtomicBorrowRefMut {
}

impl Drop for AtomicBorrowRefMut {
    fn drop(&mut self) {
    }
}

fn map(orig: AtomicRefMut) -> AtomicRefMut {
    AtomicRefMut {
        value: orig.value,
        borrow: orig.borrow,
    }
}

fn main() {}
